@@ -1,20 +1,18 @@
 import json
-import json5  # type: ignore
-from pathlib import Path
 import sys
 from http import HTTPStatus
-import pkg_resources  # type: ignore
+from pathlib import Path
 
+import json5  # type: ignore
+import pkg_resources  # type: ignore
 from babel import Locale  # type: ignore
-import jupyverse  # type: ignore
-from fastapi import Response, Depends, status
+from fastapi import Depends, Response, status
 from fastapi.responses import FileResponse, RedirectResponse
 from fastapi.staticfiles import StaticFiles
 from starlette.requests import Request  # type: ignore
 
-from fps_auth.db import get_user_db  # type: ignore
-from fps_auth.backends import current_user  # type: ignore
-from fps_auth.models import User  # type: ignore
+import jupyverse  # type: ignore
+from jupyverse import User, current_user, update_user
 
 from .config import get_lab_config  # type: ignore
 from .utils import get_federated_extensions
@@ -56,11 +54,11 @@ def init_router(router, redirect_after_root):
         name="themes",
     )
 
-    @router.get("/")
+    @router.get("/", name="root")
     async def get_root(
         response: Response,
         lab_config=Depends(get_lab_config),
-        user=Depends(current_user),
+        user: User = Depends(current_user()),
     ):
         # auto redirect
         response.status_code = status.HTTP_302_FOUND
@@ -76,10 +74,8 @@ def init_router(router, redirect_after_root):
             "https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.7/" + rest_of_path
         )
 
-    @router.get(
-        "/lab/api/listings/@jupyterlab/extensionmanager-extension/listings.json"
-    )
-    async def get_listings(user=Depends(current_user)):
+    @router.get("/lab/api/listings/@jupyterlab/extensionmanager-extension/listings.json")
+    async def get_listings(user: User = Depends(current_user())):
         return {
             "blocked_extensions_uris": [],
             "allowed_extensions_uris": [],
@@ -90,12 +86,12 @@ def init_router(router, redirect_after_root):
     @router.get("/lab/api/translations/")
     async def get_translations_(
         lab_config=Depends(get_lab_config),
-        user: User = Depends(current_user),
+        user: User = Depends(current_user()),
     ):
         return RedirectResponse(f"{lab_config.base_url}lab/api/translations")
 
     @router.get("/lab/api/translations")
-    async def get_translations(user: User = Depends(current_user)):
+    async def get_translations(user: User = Depends(current_user())):
         locale = Locale.parse("en")
         data = {
             "en": {
@@ -114,7 +110,7 @@ def init_router(router, redirect_after_root):
     @router.get("/lab/api/translations/{language}")
     async def get_translation(
         language,
-        user: User = Depends(current_user),
+        user: User = Depends(current_user()),
     ):
         global LOCALE
         if language == "en":
@@ -128,9 +124,9 @@ def init_router(router, redirect_after_root):
         LOCALE = language
         package = ep.load()
         data = {}
-        for path in (
-            Path(package.__file__).parent / "locale" / language / "LC_MESSAGES"
-        ).glob("*.json"):
+        for path in (Path(package.__file__).parent / "locale" / language / "LC_MESSAGES").glob(
+            "*.json"
+        ):
             with open(path) as f:
                 data.update({path.stem: json.load(f)})
         return {"data": data, "message": ""}
@@ -140,7 +136,7 @@ def init_router(router, redirect_after_root):
         name0,
         name1,
         name2,
-        user: User = Depends(current_user),
+        user: User = Depends(current_user()),
     ):
         with open(jlab_dir / "static" / "package.json") as f:
             package = json.load(f)
@@ -175,17 +171,16 @@ def init_router(router, redirect_after_root):
         request: Request,
         name0,
         name1,
-        user: User = Depends(current_user),
-        user_db=Depends(get_user_db),
+        user: User = Depends(current_user()),
+        user_update=Depends(update_user),
     ):
         settings = json.loads(user.settings)
         settings[f"{name0}:{name1}"] = await request.json()
-        user.settings = json.dumps(settings)
-        await user_db.update(user)
+        await user_update({"settings": json.dumps(settings)})
         return Response(status_code=HTTPStatus.NO_CONTENT.value)
 
     @router.get("/lab/api/settings")
-    async def get_settings(user: User = Depends(current_user)):
+    async def get_settings(user: User = Depends(current_user())):
         with open(jlab_dir / "static" / "package.json") as f:
             package = json.load(f)
         if user:
